@@ -305,7 +305,11 @@ ags_syncsynth_init(AgsSyncsynth *syncsynth)
   syncsynth->lower = (GtkSpinButton *) gtk_spin_button_new_with_range(AGS_SYNCSYNTH_BASE_NOTE_MIN,
 								      AGS_SYNCSYNTH_BASE_NOTE_MAX,
 								      1.0);
+  gtk_spin_button_set_digits(syncsynth->lower,
+			     2);
   syncsynth->lower->adjustment->value = -48.0;
+  gtk_spin_button_set_digits(syncsynth->lower,
+			     2);
   gtk_table_attach(table,
 		   GTK_WIDGET(syncsynth->lower),
 		   1, 2,
@@ -1473,10 +1477,10 @@ ags_syncsynth_output_map_recall(AgsSyncsynth *syncsynth,
 
 /**
  * ags_syncsynth_add_oscillator:
- * @syncsynth: the #AgsSynthsync
+ * @syncsynth: the #AgsSyncsynth
  * @oscillator: the #AgsOscillator
  * 
- * Add @oscillator to @synthsync.
+ * Add @oscillator to @syncsynth.
  * 
  * Since: 2.0.0
  */
@@ -1519,7 +1523,7 @@ ags_syncsynth_add_oscillator(AgsSyncsynth *syncsynth,
 
 /**
  * ags_syncsynth_remove_oscillator:
- * @syncsynth: the #AgsSynthsync
+ * @syncsynth: the #AgsSyncsynth
  * @nth: the nth #AgsOscillator
  * 
  * Remove nth oscillator.
