@@ -23,6 +23,8 @@
 #include <glib.h>
 #include <glib-object.h>
 
+#include <pthread.h>
+
 #include <alsa/asoundlib.h>
 
 #include <ags/libags.h>
@@ -66,7 +68,7 @@ typedef enum{
 
 struct _AgsNote
 {
-  GObject object;
+  GObject gobject;
 
   guint flags;
 
@@ -100,7 +102,7 @@ struct _AgsNote
 
 struct _AgsNoteClass
 {
-  GObjectClass object;
+  GObjectClass gobject;
 };
 
 GType ags_note_get_type();
