@@ -34,10 +34,17 @@
 #if defined(__APPLE__) || defined(__FreeBSD__) || defined(__DragonFly__)
 #include <machine/endian.h>
 #else
+#ifndef AGS_W32API
 #include <endian.h>
 #endif
+#endif
 
+#if defined(AGS_W32API)
+#include <windows.h>
+#else
 #include <dlfcn.h>
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -651,10 +658,23 @@ ags_recall_dssi_load(AgsRecallDssi *recall_dssi)
 	       NULL);
 
   if(plugin_so){
+    gboolean success;
+    
+    success = FALSE;
+
+#ifdef AGS_W32API
+    dssi_descriptor = (DSSI_Descriptor_Function) GetProcAddress(plugin_so,
+								"dssi_descriptor");
+    
+    success = (!dssi_descriptor) ? FALSE: TRUE;
+#else
     dssi_descriptor = (DSSI_Descriptor_Function) dlsym(plugin_so,
 						       "dssi_descriptor");
+  
+    success = (dlerror() == NULL) ? TRUE: FALSE;
+#endif
 
-    if(dlerror() == NULL && dssi_descriptor){
+    if(success && dssi_descriptor){
       pthread_mutex_lock(recall_mutex);
       
       recall_dssi->plugin_descriptor = 
