@@ -1,5 +1,5 @@
 /* GSequencer - Advanced GTK Sequencer
- * Copyright (C) 2005-2018 Joël Krähemann
+ * Copyright (C) 2005-2019 Joël Krähemann
  *
  * This file is part of GSequencer.
  *
@@ -22,8 +22,11 @@
 #include <ags/libags.h>
 
 #include <ags/audio/ags_audio_signal.h>
+#include <ags/audio/ags_synth_enums.h>
 #include <ags/audio/ags_audio_buffer_util.h>
 #include <ags/audio/ags_synth_util.h>
+#include <ags/audio/ags_lfo_synth_util.h>
+#include <ags/audio/ags_fm_synth_util.h>
 
 #include <math.h>
 
@@ -68,10 +71,18 @@ enum{
   PROP_FRAME_COUNT,
   PROP_LOOP_START,
   PROP_LOOP_END,
+  PROP_DO_LFO,
   PROP_OSCILLATOR,
   PROP_FREQUENCY,
   PROP_PHASE,
   PROP_VOLUME,
+  PROP_LFO_DEPTH,
+  PROP_TUNING,
+  PROP_DO_FM_SYNTH,
+  PROP_FM_LFO_OSCILLATOR,
+  PROP_FM_LFO_FREQUENCY,
+  PROP_FM_LFO_DEPTH,
+  PROP_FM_TUNING,
   PROP_TIMESTAMP,
 };
 
@@ -150,7 +161,7 @@ ags_synth_generator_class_init(AgsSynthGeneratorClass *synth_generator)
 				 i18n_pspec("The samplerate to be used"),
 				 0,
 				 G_MAXUINT32,
-				 0,
+				 AGS_SYNTH_GENERATOR_DEFAULT_SAMPLERATE,
 				 G_PARAM_READABLE | G_PARAM_WRITABLE);
   g_object_class_install_property(gobject,
 				  PROP_SAMPLERATE,
@@ -168,7 +179,7 @@ ags_synth_generator_class_init(AgsSynthGeneratorClass *synth_generator)
 				 i18n_pspec("The buffer size to be used"),
 				 0,
 				 G_MAXUINT32,
-				 0,
+				 AGS_SYNTH_GENERATOR_DEFAULT_BUFFER_SIZE,
 				 G_PARAM_READABLE | G_PARAM_WRITABLE);
   g_object_class_install_property(gobject,
 				  PROP_BUFFER_SIZE,
@@ -186,7 +197,7 @@ ags_synth_generator_class_init(AgsSynthGeneratorClass *synth_generator)
 				 i18n_pspec("The format to be used"),
 				 0,
 				 G_MAXUINT32,
-				 0,
+				 AGS_SYNTH_GENERATOR_DEFAULT_FORMAT,
 				 G_PARAM_READABLE | G_PARAM_WRITABLE);
   g_object_class_install_property(gobject,
 				  PROP_FORMAT,
@@ -282,6 +293,22 @@ ags_synth_generator_class_init(AgsSynthGeneratorClass *synth_generator)
 				  PROP_ATTACK,
 				  param_spec);
 
+  /**
+   * AgsSynthGenerator:do-lfo:
+   *
+   * If %TRUE compute LFO amplification, otherwise not.
+   * 
+   * Since: 2.3.0
+   */
+  param_spec = g_param_spec_boolean("do-lfo",
+				    i18n_pspec("do LFO amplification"),
+				    i18n_pspec("do LFO amplification"),
+				    FALSE,
+				    G_PARAM_READABLE | G_PARAM_WRITABLE);
+  g_object_class_install_property(gobject,
+				  PROP_DO_LFO,
+				  param_spec);
+
   /**
    * AgsSynthGenerator:oscillator:
    *
@@ -294,7 +321,7 @@ ags_synth_generator_class_init(AgsSynthGeneratorClass *synth_generator)
 				 i18n_pspec("The oscillator to be used"),
 				 0,
 				 G_MAXUINT32,
-				 0,
+				 AGS_SYNTH_GENERATOR_DEFAULT_OSCILLATOR,
 				 G_PARAM_READABLE | G_PARAM_WRITABLE);
   g_object_class_install_property(gobject,
 				  PROP_OSCILLATOR,
@@ -312,7 +339,7 @@ ags_synth_generator_class_init(AgsSynthGeneratorClass *synth_generator)
 				   i18n_pspec("The frequency to be used"),
 				   0.0,
 				   65535.0,
-				   0.0,
+				   AGS_SYNTH_GENERATOR_DEFAULT_FREQUENCY,
 				   G_PARAM_READABLE | G_PARAM_WRITABLE);
   g_object_class_install_property(gobject,
 				  PROP_FREQUENCY,
@@ -330,7 +357,7 @@ ags_synth_generator_class_init(AgsSynthGeneratorClass *synth_generator)
 				   i18n_pspec("The phase to be used"),
 				   0.0,
 				   65535.0,
-				   0.0,
+				   AGS_SYNTH_GENERATOR_DEFAULT_PHASE,
 				   G_PARAM_READABLE | G_PARAM_WRITABLE);
   g_object_class_install_property(gobject,
 				  PROP_PHASE,
@@ -348,12 +375,136 @@ ags_synth_generator_class_init(AgsSynthGeneratorClass *synth_generator)
 				   i18n_pspec("The volume to be used"),
 				   0.0,
 				   2.0,
-				   0.0,
+				   AGS_SYNTH_GENERATOR_DEFAULT_VOLUME,
 				   G_PARAM_READABLE | G_PARAM_WRITABLE);
   g_object_class_install_property(gobject,
 				  PROP_VOLUME,
 				  param_spec);
 
+  /**
+   * AgsAudioSignal:lfo-depth:
+   *
+   * The LFO depth to be used.
+   * 
+   * Since: 2.3.0
+   */
+  param_spec = g_param_spec_double("lfo-depth",
+				   i18n_pspec("using LFO depth"),
+				   i18n_pspec("The LFO depth to be used"),
+				   0.0,
+				   1.0,
+				   AGS_SYNTH_GENERATOR_DEFAULT_LFO_DEPTH,
+				   G_PARAM_READABLE | G_PARAM_WRITABLE);
+  g_object_class_install_property(gobject,
+				  PROP_LFO_DEPTH,
+				  param_spec);
+
+  /**
+   * AgsAudioSignal:tuning:
+   *
+   * The tuning to be used.
+   * 
+   * Since: 2.3.0
+   */
+  param_spec = g_param_spec_double("tuning",
+				   i18n_pspec("using tuning"),
+				   i18n_pspec("The tuning to be used"),
+				   0.0,
+				   1200.0,
+				   AGS_SYNTH_GENERATOR_DEFAULT_TUNING,
+				   G_PARAM_READABLE | G_PARAM_WRITABLE);
+  g_object_class_install_property(gobject,
+				  PROP_TUNING,
+				  param_spec);
+
+  /**
+   * AgsSynthGenerator:do-fm-synth:
+   *
+   * If %TRUE compute FM synth, otherwise not.
+   * 
+   * Since: 2.3.0
+   */
+  param_spec = g_param_spec_boolean("do-fm-synth",
+				    i18n_pspec("do fm synth"),
+				    i18n_pspec("do fm synth"),
+				    FALSE,
+				    G_PARAM_READABLE | G_PARAM_WRITABLE);
+  g_object_class_install_property(gobject,
+				  PROP_DO_FM_SYNTH,
+				  param_spec);
+
+  /**
+   * AgsSynthGenerator:fm-lfo-oscillator:
+   *
+   * The frame count to be used.
+   * 
+   * Since: 2.3.0
+   */
+  param_spec = g_param_spec_uint("fm-lfo-oscillator",
+				 i18n_pspec("fm LFO oscillator mode"),
+				 i18n_pspec("the frequency modulation LFO oscillator mode"),
+				 0,
+				 G_MAXUINT32,
+				 0,
+				 G_PARAM_READABLE | G_PARAM_WRITABLE);
+  g_object_class_install_property(gobject,
+				  PROP_FM_LFO_OSCILLATOR,
+				  param_spec);
+
+  /**
+   * AgsAudioSignal:fm-lfo-frequency:
+   *
+   * The fm LFO frequency to be used.
+   * 
+   * Since: 2.3.0
+   */
+  param_spec = g_param_spec_double("fm-lfo-frequency",
+				   i18n_pspec("using fm LFO frequency"),
+				   i18n_pspec("The fm LFO frequency to be used"),
+				   0.001,
+				   27.5,
+				   AGS_SYNTH_GENERATOR_DEFAULT_FM_LFO_FREQUENCY,
+				   G_PARAM_READABLE | G_PARAM_WRITABLE);
+  g_object_class_install_property(gobject,
+				  PROP_FM_LFO_FREQUENCY,
+				  param_spec);
+
+  /**
+   * AgsAudioSignal:fm-lfo-depth:
+   *
+   * The fm LFO depth to be used.
+   * 
+   * Since: 2.3.0
+   */
+  param_spec = g_param_spec_double("fm-lfo-depth",
+				   i18n_pspec("using fm LFO depth"),
+				   i18n_pspec("The fm LFO depth to be used"),
+				   0.0,
+				   1.0,
+				   AGS_SYNTH_GENERATOR_DEFAULT_FM_LFO_DEPTH,
+				   G_PARAM_READABLE | G_PARAM_WRITABLE);
+  g_object_class_install_property(gobject,
+				  PROP_FM_LFO_DEPTH,
+				  param_spec);
+
+  /**
+   * AgsAudioSignal:fm-tuning:
+   *
+   * The fm tuning to be used.
+   * 
+   * Since: 2.3.0
+   */
+  param_spec = g_param_spec_double("fm-tuning",
+				   i18n_pspec("using FM tuning"),
+				   i18n_pspec("The FM tuning to be used"),
+				   0.0,
+				   1200.0,
+				   AGS_SYNTH_GENERATOR_DEFAULT_FM_TUNING,
+				   G_PARAM_READABLE | G_PARAM_WRITABLE);
+  g_object_class_install_property(gobject,
+				  PROP_FM_TUNING,
+				  param_spec);
+
   /**
    * AgsSynthGenerator:timestamp:
    *
@@ -403,11 +554,17 @@ ags_synth_generator_init(AgsSynthGenerator *synth_generator)
   synth_generator->delay = 0.0;
   synth_generator->attack = 0;
 
-  synth_generator->oscillator = 0;
+  synth_generator->do_lfo = FALSE;
+
+  synth_generator->oscillator = AGS_SYNTH_GENERATOR_DEFAULT_OSCILLATOR;
   
-  synth_generator->frequency = 0.0;
-  synth_generator->phase = 0.0;
-  synth_generator->volume = 1.0;
+  synth_generator->frequency = AGS_SYNTH_GENERATOR_DEFAULT_FREQUENCY;
+  synth_generator->phase = AGS_SYNTH_GENERATOR_DEFAULT_PHASE;
+  synth_generator->volume = AGS_SYNTH_GENERATOR_DEFAULT_VOLUME;
+
+  synth_generator->lfo_depth = AGS_SYNTH_GENERATOR_DEFAULT_LFO_DEPTH;
+  
+  synth_generator->tuning = AGS_SYNTH_GENERATOR_DEFAULT_TUNING;
 
   synth_generator->sync_relative = FALSE;
   synth_generator->sync_point = NULL;
@@ -415,6 +572,15 @@ ags_synth_generator_init(AgsSynthGenerator *synth_generator)
 
   synth_generator->damping = ags_complex_alloc();
   synth_generator->vibration = ags_complex_alloc();
+
+  synth_generator->do_fm_synth = FALSE;
+
+  synth_generator->fm_lfo_oscillator = 0;
+
+  synth_generator->fm_lfo_frequency = AGS_SYNTH_GENERATOR_DEFAULT_FM_LFO_FREQUENCY;
+  synth_generator->fm_lfo_depth = AGS_SYNTH_GENERATOR_DEFAULT_FM_LFO_DEPTH;
+  
+  synth_generator->fm_tuning = AGS_SYNTH_GENERATOR_DEFAULT_FM_TUNING;
   
   /* timestamp */
   synth_generator->timestamp = NULL;
@@ -506,6 +672,31 @@ ags_synth_generator_set_property(GObject *gobject,
       synth_generator->volume = g_value_get_double(value);
     }
     break;
+  case PROP_DO_FM_SYNTH:
+    {
+      synth_generator->do_fm_synth = g_value_get_boolean(value);
+    }
+    break;
+  case PROP_FM_LFO_OSCILLATOR:
+    {
+      synth_generator->fm_lfo_oscillator = g_value_get_uint(value);
+    }
+    break;
+  case PROP_FM_LFO_FREQUENCY:
+    {
+      synth_generator->fm_lfo_frequency = g_value_get_double(value);
+    }
+    break;
+  case PROP_FM_LFO_DEPTH:
+    {
+      synth_generator->fm_lfo_depth = g_value_get_double(value);
+    }
+    break;
+  case PROP_FM_TUNING:
+    {
+      synth_generator->fm_tuning = g_value_get_double(value);
+    }
+    break;
   case PROP_TIMESTAMP:
     {
       AgsTimestamp *timestamp;
@@ -561,7 +752,7 @@ ags_synth_generator_get_property(GObject *gobject,
     break;
   case PROP_DELAY:
     {
-      g_value_set_uint(value, synth_generator->delay);
+      g_value_set_double(value, synth_generator->delay);
     }
     break;
   case PROP_ATTACK:
@@ -591,17 +782,37 @@ ags_synth_generator_get_property(GObject *gobject,
     break;
   case PROP_FREQUENCY:
     {
-      g_value_set_uint(value, synth_generator->frequency);
+      g_value_set_double(value, synth_generator->frequency);
     }
     break;
   case PROP_PHASE:
     {
-      g_value_set_uint(value, synth_generator->phase);
+      g_value_set_double(value, synth_generator->phase);
     }
     break;
-  case PROP_VOLUME:
+  case PROP_DO_FM_SYNTH:
     {
-      g_value_set_uint(value, synth_generator->volume);
+      g_value_set_boolean(value, synth_generator->do_fm_synth);
+    }
+    break;
+  case PROP_FM_LFO_OSCILLATOR:
+    {
+      g_value_set_uint(value, synth_generator->fm_lfo_oscillator);
+    }
+    break;
+  case PROP_FM_LFO_FREQUENCY:
+    {
+      g_value_set_double(value, synth_generator->fm_lfo_frequency);
+    }
+    break;
+  case PROP_FM_LFO_DEPTH:
+    {
+      g_value_set_double(value, synth_generator->fm_lfo_depth);
+    }
+    break;
+  case PROP_FM_TUNING:
+    {
+      g_value_set_double(value, synth_generator->fm_tuning);
     }
     break;
   case PROP_TIMESTAMP:
@@ -790,9 +1001,13 @@ ags_synth_generator_compute(AgsSynthGenerator *synth_generator,
   guint frame_count;
   guint buffer_size;
   guint current_frame_count, requested_frame_count;
+  gboolean do_lfo;
+  guint oscillator;
   gdouble samplerate;
   gdouble current_frequency;
   gdouble phase, volume;
+  gdouble lfo_depth;
+  gdouble tuning;
   gdouble current_phase;
   guint format;
   guint audio_buffer_util_format;
@@ -802,6 +1017,11 @@ ags_synth_generator_compute(AgsSynthGenerator *synth_generator,
   guint i, j;
   AgsComplex **sync_point;
   guint sync_point_count;
+  gboolean do_fm_synth;
+  guint fm_lfo_osc_mode;
+  gdouble fm_lfo_freq; 
+  gdouble fm_lfo_depth;
+  gdouble fm_tuning;
   gboolean synced;
 
   delay = synth_generator->delay;
@@ -811,6 +1031,10 @@ ags_synth_generator_compute(AgsSynthGenerator *synth_generator,
   
   buffer_size = AGS_AUDIO_SIGNAL(audio_signal)->buffer_size;
 
+  do_lfo = synth_generator->do_lfo;
+
+  oscillator = synth_generator->oscillator;
+  
   sync_point = synth_generator->sync_point;
   sync_point_count = synth_generator->sync_point_count;
 
@@ -844,6 +1068,9 @@ ags_synth_generator_compute(AgsSynthGenerator *synth_generator,
   format = AGS_AUDIO_SIGNAL(audio_signal)->format;
   audio_buffer_util_format = ags_audio_buffer_util_format_from_soundcard(format);
 
+  lfo_depth = synth_generator->lfo_depth;
+  tuning = synth_generator->tuning;
+
   current_attack = attack;
   current_count = buffer_size;
   
@@ -872,12 +1099,52 @@ ags_synth_generator_compute(AgsSynthGenerator *synth_generator,
       }
     }
   }
+
+  do_fm_synth = synth_generator->do_fm_synth;
+
+  fm_lfo_osc_mode = 0;
   
+  switch(synth_generator->fm_lfo_oscillator){
+  case AGS_SYNTH_GENERATOR_OSCILLATOR_SIN:
+  {
+    fm_lfo_osc_mode = AGS_SYNTH_OSCILLATOR_SIN;
+  }
+  break;
+  case AGS_SYNTH_GENERATOR_OSCILLATOR_SAWTOOTH:
+  {
+    fm_lfo_osc_mode = AGS_SYNTH_OSCILLATOR_SAWTOOTH;
+  }
+  break;
+  case AGS_SYNTH_GENERATOR_OSCILLATOR_TRIANGLE:
+  {
+    fm_lfo_osc_mode = AGS_SYNTH_OSCILLATOR_TRIANGLE;
+  }
+  break;
+  case AGS_SYNTH_GENERATOR_OSCILLATOR_SQUARE:
+  {
+    fm_lfo_osc_mode = AGS_SYNTH_OSCILLATOR_SQUARE;
+  }
+  break;
+  case AGS_SYNTH_GENERATOR_OSCILLATOR_IMPULSE:
+  {
+    fm_lfo_osc_mode = AGS_SYNTH_OSCILLATOR_IMPULSE;
+  }
+  break;
+  }
+  
+  fm_lfo_freq = synth_generator->fm_lfo_frequency;
+  fm_lfo_depth = synth_generator->fm_lfo_depth;
+
+  fm_tuning = synth_generator->fm_tuning;
+
   synced = FALSE;
   
   for(i = attack, j = 0; i < frame_count + attack && stream != NULL;){
-    switch(synth_generator->oscillator){
-    case AGS_SYNTH_GENERATOR_OSCILLATOR_SIN:
+
+    if(!do_fm_synth && !do_lfo){
+
+      switch(oscillator){
+      case AGS_SYNTH_GENERATOR_OSCILLATOR_SIN:
       {
 	ags_synth_util_sin(stream->data,
 			   current_frequency, current_phase, volume,
@@ -885,7 +1152,7 @@ ags_synth_generator_compute(AgsSynthGenerator *synth_generator,
 			   current_attack, current_count);
       }
       break;
-    case AGS_SYNTH_GENERATOR_OSCILLATOR_SAWTOOTH:
+      case AGS_SYNTH_GENERATOR_OSCILLATOR_SAWTOOTH:
       {
 	ags_synth_util_sawtooth(stream->data,
 				current_frequency, current_phase, volume,
@@ -893,7 +1160,7 @@ ags_synth_generator_compute(AgsSynthGenerator *synth_generator,
 				current_attack, current_count);
       }
       break;
-    case AGS_SYNTH_GENERATOR_OSCILLATOR_TRIANGLE:
+      case AGS_SYNTH_GENERATOR_OSCILLATOR_TRIANGLE:
       {
 	ags_synth_util_triangle(stream->data,
 				current_frequency, current_phase, volume,
@@ -901,7 +1168,7 @@ ags_synth_generator_compute(AgsSynthGenerator *synth_generator,
 				current_attack, current_count);
       }
       break;
-    case AGS_SYNTH_GENERATOR_OSCILLATOR_SQUARE:
+      case AGS_SYNTH_GENERATOR_OSCILLATOR_SQUARE:
       {
 	ags_synth_util_square(stream->data,
 			      current_frequency, current_phase, volume,
@@ -909,10 +1176,139 @@ ags_synth_generator_compute(AgsSynthGenerator *synth_generator,
 			      current_attack, current_count);
       }
       break;
-    default:
-      g_message("unknown oscillator");
-    }
+      case AGS_SYNTH_GENERATOR_OSCILLATOR_IMPULSE:
+      {
+	ags_synth_util_impulse(stream->data,
+			       current_frequency, current_phase, volume,
+			       samplerate, audio_buffer_util_format,
+			       current_attack, current_count);
+      }
+      break;
+      default:
+	g_message("unknown oscillator");
+      }
 
+    }else if(do_lfo){
+
+      switch(oscillator){
+      case AGS_SYNTH_GENERATOR_OSCILLATOR_SIN:
+      {
+	ags_lfo_synth_util_sin(stream->data,
+			       current_frequency, current_phase,
+			       lfo_depth,
+			       tuning,
+			       samplerate, audio_buffer_util_format,
+			       current_attack, current_count);
+      }
+      break;
+      case AGS_SYNTH_GENERATOR_OSCILLATOR_SAWTOOTH:
+      {
+	ags_lfo_synth_util_sawtooth(stream->data,
+				    current_frequency, current_phase,
+				    lfo_depth,
+				    tuning,
+				    samplerate, audio_buffer_util_format,
+				    current_attack, current_count);
+      }
+      break;
+      case AGS_SYNTH_GENERATOR_OSCILLATOR_TRIANGLE:
+      {
+	ags_lfo_synth_util_triangle(stream->data,
+				    current_frequency, current_phase,
+				    lfo_depth,
+				    tuning,
+				    samplerate, audio_buffer_util_format,
+				    current_attack, current_count);
+      }
+      break;
+      case AGS_SYNTH_GENERATOR_OSCILLATOR_SQUARE:
+      {
+	ags_lfo_synth_util_square(stream->data,
+				  current_frequency, current_phase,
+				  lfo_depth,
+				  tuning,
+				  samplerate, audio_buffer_util_format,
+				  current_attack, current_count);
+      }
+      break;
+      case AGS_SYNTH_GENERATOR_OSCILLATOR_IMPULSE:
+      {
+	ags_lfo_synth_util_impulse(stream->data,
+				   current_frequency, current_phase,
+				   lfo_depth,
+				   tuning,
+				   samplerate, audio_buffer_util_format,
+				   current_attack, current_count);
+      }
+      break;
+      default:
+	g_message("unknown oscillator");
+      }
+
+    }else if(do_fm_synth){
+
+      switch(synth_generator->oscillator){
+      case AGS_SYNTH_GENERATOR_OSCILLATOR_SIN:
+      {
+	ags_fm_synth_util_sin(stream->data,
+			      current_frequency, current_phase, volume,
+			      samplerate, audio_buffer_util_format,
+			      current_attack, current_count,
+			      fm_lfo_osc_mode,
+			      fm_lfo_freq, fm_lfo_depth,
+			      fm_tuning);
+      }
+      break;
+      case AGS_SYNTH_GENERATOR_OSCILLATOR_SAWTOOTH:
+      {
+	ags_fm_synth_util_sawtooth(stream->data,
+				   current_frequency, current_phase, volume,
+				   samplerate, audio_buffer_util_format,
+				   current_attack, current_count,
+				   fm_lfo_osc_mode,
+				   fm_lfo_freq, fm_lfo_depth,
+				   fm_tuning);
+      }
+      break;
+      case AGS_SYNTH_GENERATOR_OSCILLATOR_TRIANGLE:
+      {
+	ags_fm_synth_util_triangle(stream->data,
+				   current_frequency, current_phase, volume,
+				   samplerate, audio_buffer_util_format,
+				   current_attack, current_count,
+				   fm_lfo_osc_mode,
+				   fm_lfo_freq, fm_lfo_depth,
+				   fm_tuning);
+      }
+      break;
+      case AGS_SYNTH_GENERATOR_OSCILLATOR_SQUARE:
+      {
+	ags_fm_synth_util_square(stream->data,
+				 current_frequency, current_phase, volume,
+				 samplerate, audio_buffer_util_format,
+				 current_attack, current_count,
+				 fm_lfo_osc_mode,
+				 fm_lfo_freq, fm_lfo_depth,
+				 fm_tuning);
+      }
+      break;
+      case AGS_SYNTH_GENERATOR_OSCILLATOR_IMPULSE:
+      {
+	ags_fm_synth_util_impulse(stream->data,
+				  current_frequency, current_phase, volume,
+				  samplerate, audio_buffer_util_format,
+				  current_attack, current_count,
+				  fm_lfo_osc_mode,
+				  fm_lfo_freq, fm_lfo_depth,
+				  fm_tuning);
+      }
+      break;
+      default:
+	g_message("unknown oscillator");
+      }
+
+    }
+    
     if(current_frequency == 0.0){
       current_phase = (guint) ((offset + current_count) + phase);
     }else if(floor(samplerate / current_frequency) == 0){
