@@ -1,5 +1,5 @@
 /* GSequencer - Advanced GTK Sequencer
- * Copyright (C) 2005-2018 Joël Krähemann
+ * Copyright (C) 2005-2019 Joël Krähemann
  *
  * This file is part of GSequencer.
  *
@@ -257,11 +257,7 @@ ags_copy_pattern_audio_set_property(GObject *gobject,
   copy_pattern_audio = AGS_COPY_PATTERN_AUDIO(gobject);
 
   /* get recall mutex */
-  pthread_mutex_lock(ags_recall_get_class_mutex());
-  
-  recall_mutex = AGS_RECALL(gobject)->obj_mutex;
-
-  pthread_mutex_unlock(ags_recall_get_class_mutex());
+  recall_mutex = AGS_RECALL_GET_OBJ_MUTEX(copy_pattern_audio);
 
   switch(prop_id){
   case PROP_BANK_INDEX_0:
@@ -337,11 +333,7 @@ ags_copy_pattern_audio_get_property(GObject *gobject,
   copy_pattern_audio = AGS_COPY_PATTERN_AUDIO(gobject);
 
   /* get recall mutex */
-  pthread_mutex_lock(ags_recall_get_class_mutex());
-  
-  recall_mutex = AGS_RECALL(gobject)->obj_mutex;
-
-  pthread_mutex_unlock(ags_recall_get_class_mutex());
+  recall_mutex = AGS_RECALL_GET_OBJ_MUTEX(copy_pattern_audio);
 
   switch(prop_id){
   case PROP_BANK_INDEX_0:
