@@ -1,4 +1,4 @@
-</* GSequencer - Advanced GTK Sequencer
+/* GSequencer - Advanced GTK Sequencer
  * Copyright (C) 2005-2018 Joël Krähemann
  *
  * This file is part of GSequencer.
