@@ -19,7 +19,7 @@
 
 #include <ags/server/security/ags_certificate.h>
 
-void ags_certificate_base_init(AgsCertificateInterface *interface);
+void ags_certificate_base_init(AgsCertificateInterface *ginterface);
 
 /**
  * SECTION:ags_certificate
@@ -57,7 +57,7 @@ ags_certificate_get_type()
 }
 
 void
-ags_certificate_base_init(AgsCertificateInterface *interface)
+ags_certificate_base_init(AgsCertificateInterface *ginterface)
 {
   /* empty */
 }
